==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/EventDatumValueSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.value.EventDatumValue;
import io.ciera.tool.sql.ooaofooa.value.EventDatumValueSet;
import io.ciera.tool.sql.ooaofooa.value.EventParameterReferenceSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.EventParameterReferenceSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class EventDatumValueSetImpl extends InstanceSet<EventDatumValueSet,EventDatumValue> implements EventDatumValueSet {

    // attributes
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( EventDatumValue eventdatumvalue : this ) eventdatumvalue.setValue_ID( ref_Value_ID );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( EventDatumValue eventdatumvalue : this ) valueset.add( eventdatumvalue.R801_is_a_Value() );
        return valueset;
    }
    @Override
    public EventParameterReferenceSet R834_EventParameterReference() throws XtumlException {
        EventParameterReferenceSet eventparameterreferenceset = new EventParameterReferenceSetImpl();
        for ( EventDatumValue eventdatumvalue : this ) eventparameterreferenceset.addAll( eventdatumvalue.R834_EventParameterReference() );
        return eventparameterreferenceset;
    }


    @Override
    public EventDatumValue nullElement() {
        return EventDatumValueImpl.EMPTY_EVENTDATUMVALUE;
    }

    @Override
    public EventDatumValueSet emptySet() {
      return new EventDatumValueSetImpl();
    }

    @Override
    public EventDatumValueSet value() {
        return this;
    }

    @Override
    public List<EventDatumValue> elements() {
        return Arrays.asList(toArray(new EventDatumValue[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/EventDatumValueSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.value.EventDatumValue;
import io.ciera.tool.sql.ooaofooa.value.EventDatumValueSet;
import io.ciera.tool.sql.ooaofooa.value.EventParameterReferenceSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.EventParameterReferenceSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class EventDatumValueSetImpl extends InstanceSet<EventDatumValueSet,EventDatumValue> implements EventDatumValueSet {

    public EventDatumValueSetImpl() {
    }

    public EventDatumValueSetImpl(Comparator<? super EventDatumValue> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( EventDatumValue eventdatumvalue : this ) eventdatumvalue.setValue_ID( ref_Value_ID );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( EventDatumValue eventdatumvalue : this ) valueset.add( eventdatumvalue.R801_is_a_Value() );
        return valueset;
    }
    @Override
    public EventParameterReferenceSet R834_EventParameterReference() throws XtumlException {
        EventParameterReferenceSet eventparameterreferenceset = new EventParameterReferenceSetImpl();
        for ( EventDatumValue eventdatumvalue : this ) eventparameterreferenceset.addAll( eventdatumvalue.R834_EventParameterReference() );
        return eventparameterreferenceset;
    }


    @Override
    public EventDatumValue nullElement() {
        return EventDatumValueImpl.EMPTY_EVENTDATUMVALUE;
    }

    @Override
    public EventDatumValueSet emptySet() {
      return new EventDatumValueSetImpl();
    }

    @Override
    public EventDatumValueSet emptySet(Comparator<? super EventDatumValue> comp) {
      return new EventDatumValueSetImpl(comp);
    }

    @Override
    public EventDatumValueSet value() {
        return this;
    }

    @Override
    public List<EventDatumValue> elements() {
        return Arrays.asList(toArray(new EventDatumValue[0]));
    }

}
